==> xwidgetsbase-9.7.1.tar.gz: lib/XPlayer.dart <==
import 'dart:async';
import 'dart:html';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'package:xwidgetsbase/XMainDash_Base.dart';
import 'package:xwidgetsbase/XStylesBase.dart';
import 'package:intl/intl.dart';
import 'package:xwidgetsbase/xWidgetsBase.dart';

class XPlayer<T> extends StatefulWidget {
  XPlayer(
    this.liDashBoardIndexesToShow, {
    Key? key,
    this.dataIsNull,
    this.appName,
    this.clock,
    this.appVersion,
    this.backGroundColor,
  }) : super(key: key);
  List<int> liDashBoardIndexesToShow;
  static List<XDashboard> liXDashBoard = List<XDashboard>.empty(growable: true);
  bool? dataIsNull;
  String? appName;
  String? appVersion;
  Color? backGroundColor;
  String? clock;
  @override
  _XPlayerState<T> createState() => _XPlayerState<T>();
}

class _XPlayerState<T> extends State<XPlayer<T>> {
  int currentDashIdx = -1;
  int currentPlayerIdx = 0;
  Timer? timerClock;
  String clock = "";
  bool isActive_XPlayer = true;
  XDashboard? xDashboardActive;

  @override
  void initState() {
    currentDashIdx = widget.liDashBoardIndexesToShow[0];
    super.initState();
  }

  cmd_Play() {
    if (isActive_XPlayer) {
      xDashboardActive?.onTimeOut = null; //non chiamerà un cazzo!
    } else {
      cmd_Next();
    }
    setState(() {
      isActive_XPlayer = isActive_XPlayer.not();
    });
  }

  cmd_Next() {
    currentPlayerIdx++;
    if (currentPlayerIdx >= widget.liDashBoardIndexesToShow.length) currentPlayerIdx = 0;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  cmd_Previous() {
    currentPlayerIdx--;
    if (currentPlayerIdx < 0) currentPlayerIdx = widget.liDashBoardIndexesToShow.length - 1;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  xBuilder_ToolBar() {
    return Container(
        margin: EdgeInsets.only(right: 100, top: 2),
        child: Row(mainAxisSize: MainAxisSize.min, children: [
          isActive_XPlayer ? XBtnbase(marginBTN: EdgeInsets.all(5), icon: Icons.skip_previous_outlined, iconColor: Colors.grey, widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)) : XBtnbase(marginBTN: EdgeInsets.all(5), icon: Icons.skip_previous_outlined, iconColor: Colors.white, onPressed: () => cmd_Next(), widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)),
          XBtnbase(marginBTN: EdgeInsets.all(5), icon: isActive_XPlayer ? Icons.pause : Icons.play_arrow_outlined, iconColor: isActive_XPlayer ? Colors.white : Colors.orange, onPressed: () => cmd_Play(), widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)),
          isActive_XPlayer ? XBtnbase(marginBTN: EdgeInsets.all(5), icon: Icons.skip_next_outlined, iconColor: Colors.grey, widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)) : XBtnbase(marginBTN: EdgeInsets.all(5), icon: Icons.skip_next_outlined, iconColor: Colors.white, onPressed: () => cmd_Previous(), widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)),
        ]));
  }

  appBarForDash(String typeOfDash) {
    return XAppBar(
      height: 40,
      backGroundColor: widget.backGroundColor ?? Colors.black,
      title: widget.appName! + " v." + widget.appVersion!,
      title_Widget: Row(crossAxisAlignment: CrossAxisAlignment.end, mainAxisSize: MainAxisSize.min, children: [
        Flexible(
            child: Text(widget.appName!.toUpperCase() + " v." + widget.appVersion!,
                style: XStyles.xStyleText(
                  colorText: MainDashBase.appColor_AppName,
                  letterSpacing: 1.5,
                  fontSize: 30,
                )))
      ]),
      title_fontSize: 14,
      title_letterSpacing: 1.5,
      leading_Width: 400,
      leading_Widget: Container(
        child: Text(typeOfDash.toUpperCase(), style: XStyles.xStyTextForSubDescr(MainDashBase.appColor_BackGroundLight)),
        margin: EdgeInsets.only(top: 8, left: 8),
      ),
      actions: [
        xBuilder_ToolBar(),
        Container(
            margin: EdgeInsets.only(right: 10),
            alignment: Alignment.center,
            child: widget.dataIsNull == false
                ? Text("NO CONNESSIONE", style: XStyles.xStyleText(colorText: Colors.red, fontSize: 30)) //
                : Container(child: Text("DASHBOARD v.${widget.appVersion} delle ${clock}", style: XStyles.xStyTextForTextBase(MainDashBase.appColor_BackGroundLight))))
      ],
    );
  }

//bool wasInWait=false;
  @override
  Widget build(BuildContext context) {
    /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP

    if (widget.dataIsNull != false) {
      ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
      return Consumer<T>(builder: (context, appState, _) {
        return Scaffold(appBar: appBarForDash("" + XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx).xKey), body: _BuilderTypeOfDash());
      });
    } else {
      ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
      return Consumer<T>(builder: (context, appState, _) {
        return Scaffold(
            appBar: appBarForDash("" + XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx).xKey),
            body: MainDashBase.labelForNullDash_Widget ??
                Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                  Container(
                    alignment: Alignment.center,
                    child: Text(MainDashBase.labelForNullDash ?? "... in attesa dei dati ...", style: XStyles.xStyleText(fontSize: 100, colorText: Colors.white)),
                  )
                ]));
      });
    }
  }

  changeScreenFromTimer() {
    currentPlayerIdx++;
    if (currentPlayerIdx >= widget.liDashBoardIndexesToShow.length) currentPlayerIdx = 0;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  _BuilderTypeOfDash() {
    xDashboardActive = XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx);
    if (isActive_XPlayer) {
      if (xDashboardActive?.onTimeOut == null) {
        xDashboardActive?.onTimeOut = (value) {
          changeScreenFromTimer();
        };
      }
    } else {
      xDashboardActive?.onTimeOut = null;
    }
    return xDashboardActive;
  }
}

class XDashboard extends StatefulWidget {
  XDashboard(this.idx, this.xKey, this.child, {this.onTimeOut, this.timeOfView = 5, Key? key}) : super(key: key);
  String xKey = "";
  Widget? child;
  int idx = 0;
  int timeOfView;
  Function(XDashboard)? onTimeOut;
  @override
  _XDashboardState createState() => _XDashboardState();
}

class _XDashboardState extends State<XDashboard> {
  @override
  void initState() {
    super.initState();
  }

  startTimer() {
    var d = Duration(seconds: widget.timeOfView);
    final timer = Timer.periodic(d, (x) {
      x.cancel();
      if (widget.onTimeOut != null) widget.onTimeOut!(widget);
    });

    if (widget.onTimeOut == null) {
      timer.cancel();
    } else {
      timer;
    }
  }

  @override
  Widget build(BuildContext context) {
    startTimer();
    return widget.child ?? Container();
  }
}

==> xwidgetsbase-9.7.4.tar.gz: lib/XPlayer.dart <==
import 'dart:async';
import 'dart:html';
import 'package:flutter/material.dart';
import 'package:provider/provider.dart';
import 'package:xtoolspackage/xtoolspackage.dart';
import 'package:xwidgetsbase/XMainDash_Base.dart';
import 'package:xwidgetsbase/XStylesBase.dart';
import 'package:intl/intl.dart';
import 'package:xwidgetsbase/xWidgetsBase.dart';

class XPlayer<T> extends StatefulWidget {
  XPlayer(
    this.liDashBoardIndexesToShow, {
    Key? key,
    this.dataIsNull,
    this.appName,
    this.clock,
    this.appVersion,
    this.backGroundColor,
  }) : super(key: key);
  List<int> liDashBoardIndexesToShow;
  static List<XDashboard> liXDashBoard = List<XDashboard>.empty(growable: true);
  bool? dataIsNull;
  String? appName;
  String? appVersion;
  Color? backGroundColor;
  String? clock;
  @override
  _XPlayerState<T> createState() => _XPlayerState<T>();
}

class _XPlayerState<T> extends State<XPlayer<T>> {
  int currentDashIdx = -1;
  int currentPlayerIdx = 0;
  Timer? timerClock;
  bool isActive_XPlayer = true;
  XDashboard? xDashboardActive;

  @override
  void initState() {
    currentDashIdx = widget.liDashBoardIndexesToShow[0];
    super.initState();
  }

  cmd_Play() {
    if (isActive_XPlayer) {
      xDashboardActive?.onTimeOut = null; //non chiamerà un cazzo!
    } else {
      cmd_Next();
    }
    setState(() {
      isActive_XPlayer = isActive_XPlayer.not();
    });
  }

  cmd_Next() {
    currentPlayerIdx++;
    if (currentPlayerIdx >= widget.liDashBoardIndexesToShow.length) currentPlayerIdx = 0;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  cmd_Previous() {
    currentPlayerIdx--;
    if (currentPlayerIdx < 0) currentPlayerIdx = widget.liDashBoardIndexesToShow.length - 1;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  xBuilder_ToolBar() {
    return Container(
        margin: EdgeInsets.only(right: 100, top: 2),
        child: Row(mainAxisSize: MainAxisSize.min, children: [
          isActive_XPlayer ? XBtnbase(marginBTN: EdgeInsets.all(5), icon: Icons.skip_previous_outlined, iconColor: Colors.grey, widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)) : XBtnbase(marginBTN: EdgeInsets.all(5), icon: Icons.skip_previous_outlined, iconColor: Colors.white, onPressed: () => cmd_Next(), widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)),
          XBtnbase(marginBTN: EdgeInsets.all(5), icon: isActive_XPlayer ? Icons.pause : Icons.play_arrow_outlined, iconColor: isActive_XPlayer ? Colors.white : Colors.orange, onPressed: () => cmd_Play(), widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)),
          isActive_XPlayer ? XBtnbase(marginBTN: EdgeInsets.all(5), icon: Icons.skip_next_outlined, iconColor: Colors.grey, widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)) : XBtnbase(marginBTN: EdgeInsets.all(5), icon: Icons.skip_next_outlined, iconColor: Colors.white, onPressed: () => cmd_Previous(), widthBTN: 40, heightBTN: 40, colorBTN: Colors.blue.withAlpha(100)),
        ]));
  }

  appBarForDash(String typeOfDash) {
    return XAppBar(
      height: 40,
      backGroundColor: widget.backGroundColor ?? Colors.black,
      title: widget.appName! + " v." + widget.appVersion!,
      title_Widget: Row(crossAxisAlignment: CrossAxisAlignment.end, mainAxisSize: MainAxisSize.min, children: [
        Flexible(
            child: Text(widget.appName!.toUpperCase() + " v." + widget.appVersion!,
                style: XStyles.xStyleText(
                  colorText: MainDashBase.appColor_AppName,
                  letterSpacing: 1.5,
                  fontSize: 30,
                )))
      ]),
      title_fontSize: 14,
      title_letterSpacing: 1.5,
      leading_Width: 400,
      leading_Widget: Container(
        child: Text(typeOfDash.toUpperCase(), style: XStyles.xStyTextForSubDescr(MainDashBase.appColor_BackGroundLight)),
        margin: EdgeInsets.only(top: 8, left: 8),
      ),
      actions: [
        xBuilder_ToolBar(),
        Container(
            margin: EdgeInsets.only(right: 10),
            alignment: Alignment.center,
            child: widget.dataIsNull == false
                ? Text("NO CONNESSIONE", style: XStyles.xStyleText(colorText: Colors.red, fontSize: 30)) //
                : Container(child: Text("DASHBOARD v.${widget.appVersion} aggiornata alle ${widget.clock ?? ""}", style: XStyles.xStyTextForTextBase(MainDashBase.appColor_BackGroundLight))))
      ],
    );
  }

//bool wasInWait=false;
  @override
  Widget build(BuildContext context) {
    /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP /// PARTE DA MODIFICARE PER OGNI APP

    if (widget.dataIsNull != false) {
      ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
      return Consumer<T>(builder: (context, appState, _) {
        return Scaffold(appBar: appBarForDash("" + XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx).xKey), body: _BuilderTypeOfDash());
      });
    } else {
      ///Ritorno l'XPlayer per Farmi gestire change dello screen e la lista delle Dash
      return Consumer<T>(builder: (context, appState, _) {
        return Scaffold(
            appBar: appBarForDash("" + XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx).xKey),
            body: MainDashBase.labelForNullDash_Widget ??
                Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                  Container(
                    alignment: Alignment.center,
                    child: Text(MainDashBase.labelForNullDash ?? "... in attesa dei dati ...", style: XStyles.xStyleText(fontSize: 100, colorText: Colors.white)),
                  )
                ]));
      });
    }
  }

  changeScreenFromTimer() {
    currentPlayerIdx++;
    if (currentPlayerIdx >= widget.liDashBoardIndexesToShow.length) currentPlayerIdx = 0;
    setState(() {
      currentDashIdx = widget.liDashBoardIndexesToShow[currentPlayerIdx];
    });
  }

  _BuilderTypeOfDash() {
    xDashboardActive = XPlayer.liXDashBoard.firstWhere((element) => element.idx == currentDashIdx);
    if (isActive_XPlayer) {
      if (xDashboardActive?.onTimeOut == null) {
        xDashboardActive?.onTimeOut = (value) {
          changeScreenFromTimer();
        };
      }
    } else {
      xDashboardActive?.onTimeOut = null;
    }
    return xDashboardActive;
  }
}

class XDashboard extends StatefulWidget {
  XDashboard(this.idx, this.xKey, this.child, {this.onTimeOut, this.timeOfView = 5, Key? key}) : super(key: key);
  String xKey = "";
  Widget? child;
  int idx = 0;
  int timeOfView;
  Function(XDashboard)? onTimeOut;
  @override
  _XDashboardState createState() => _XDashboardState();
}

class _XDashboardState extends State<XDashboard> {
  @override
  void initState() {
    super.initState();
  }

  startTimer() {
    var d = Duration(seconds: widget.timeOfView);
    final timer = Timer.periodic(d, (x) {
      x.cancel();
      if (widget.onTimeOut != null) widget.onTimeOut!(widget);
    });

    if (widget.onTimeOut == null) {
      timer.cancel();
    } else {
      timer;
    }
  }

  @override
  Widget build(BuildContext context) {
    startTimer();
    return widget.child ?? Container();
  }
}
